==> regex-jinja-specific-1.0.1.tgz: package/README.md <==
# regex-jinja-specific

> Regular expression for detecting Python-specific Jinja code

<div class="package-badges">
  <a href="https://www.npmjs.com/package/regex-jinja-specific" rel="nofollow noreferrer noopener">
    <img src="https://img.shields.io/badge/-npm-blue?style=flat-square" alt="page on npm">
  </a>
  <a href="https://codsen.com/os/regex-jinja-specific" rel="nofollow noreferrer noopener">
    <img src="https://img.shields.io/badge/-codsen-blue?style=flat-square" alt="page on codsen.com">
  </a>
  <a href="https://git.sr.ht/~royston/codsen/tree/master/packages/regex-jinja-specific" rel="nofollow noreferrer noopener">
    <img src="https://img.shields.io/badge/-sourcehut-blue?style=flat-square" alt="page on sourcehut">
  </a>
  <a href="https://npmcharts.com/compare/regex-jinja-specific?interval=30" rel="nofollow noreferrer noopener" target="_blank">
    <img src="https://img.shields.io/npm/dm/regex-jinja-specific.svg?style=flat-square" alt="Downloads per month">
  </a>
  <a href="https://prettier.io" rel="nofollow noreferrer noopener" target="_blank">
    <img src="https://img.shields.io/badge/code_style-prettier-brightgreen.svg?style=flat-square" alt="Code style: prettier">
  </a>
  <img src="https://img.shields.io/badge/licence-MIT-brightgreen.svg?style=flat-square" alt="MIT License">
  <a href="https://liberamanifesto.com" rel="nofollow noreferrer noopener" target="_blank">
    <img src="https://img.shields.io/badge/libera-manifesto-lightgrey.svg?style=flat-square" alt="libera manifesto">
  </a>
</div>

## Install

```bash
npm i regex-jinja-specific
```

## Quick Take

```js
import { strict as assert } from "assert";
import isJinjaSpecific from "regex-jinja-specific";

assert.equal(
  isJinjaSpecific().test(`<div>{{ '%.2f'|format(3.1415926) }}</div>`),
  true
);

// in case of ambiguous, Nunjucks-or-Jinja code
assert.equal(isJinjaSpecific().test(`<div>{{ value }}</div>`), false);
```

## Documentation

Please [visit codsen.com](https://codsen.com/os/regex-jinja-specific/) for a full description of the API and examples.

## Licence

MIT License

Copyright (c) 2010-2020 Roy Revelt and other contributors

<img src="https://codsen.com/images/png-codsen-ok.png" width="98" alt="ok" align="center"> <img src="https://codsen.com/images/png-codsen-1.png" width="148" alt="codsen" align="center"> <img src="https://codsen.com/images/png-codsen-star-small.png" width="32" alt="star" align="center">

==> regex-jinja-specific-2.0.0.tgz: package/README.md <==
# regex-jinja-specific

> Regular expression for detecting Python-specific Jinja code

<div class="package-badges">
  <a href="https://www.npmjs.com/package/regex-jinja-specific" rel="nofollow noreferrer noopener">
    <img src="https://img.shields.io/badge/-npm-blue?style=flat-square" alt="page on npm">
  </a>
  <a href="https://codsen.com/os/regex-jinja-specific" rel="nofollow noreferrer noopener">
    <img src="https://img.shields.io/badge/-codsen-blue?style=flat-square" alt="page on codsen.com">
  </a>
  <a href="https://github.com/codsen/codsen/tree/main/packages/regex-jinja-specific" rel="nofollow noreferrer noopener">
    <img src="https://img.shields.io/badge/-github-blue?style=flat-square" alt="page on github">
  </a>
  <a href="https://npmcharts.com/compare/regex-jinja-specific?interval=30" rel="nofollow noreferrer noopener" target="_blank">
    <img src="https://img.shields.io/npm/dm/regex-jinja-specific.svg?style=flat-square" alt="Downloads per month">
  </a>
  <a href="https://prettier.io" rel="nofollow noreferrer noopener" target="_blank">
    <img src="https://img.shields.io/badge/code_style-prettier-brightgreen.svg?style=flat-square" alt="Code style: prettier">
  </a>
  <img src="https://img.shields.io/badge/licence-MIT-brightgreen.svg?style=flat-square" alt="MIT License">
  <a href="https://liberamanifesto.com" rel="nofollow noreferrer noopener" target="_blank">
    <img src="https://img.shields.io/badge/libera-manifesto-lightgrey.svg?style=flat-square" alt="libera manifesto">
  </a>
</div>

## Install

```bash
npm i regex-jinja-specific
```

## Quick Take

```js
import { strict as assert } from "assert";
import { isJinjaSpecific } from "regex-jinja-specific";

assert.equal(
  isJinjaSpecific().test(`<div>{{ '%.2f'|format(3.1415926) }}</div>`),
  true
);

// in case of ambiguous, Nunjucks-or-Jinja code
assert.equal(isJinjaSpecific().test(`<div>{{ value }}</div>`), false);
```

## Documentation

Please [visit codsen.com](https://codsen.com/os/regex-jinja-specific/) for a full description of the API and examples.

## Licence

MIT License

Copyright (c) 2010-2021 Roy Revelt and other contributors

<img src="https://codsen.com/images/png-codsen-ok.png" width="98" alt="ok" align="center"> <img src="https://codsen.com/images/png-codsen-1.png" width="148" alt="codsen" align="center"> <img src="https://codsen.com/images/png-codsen-star-small.png" width="32" alt="star" align="center">
